# Chat

## Completions

Types:

```python
from propulsionai.types.chat import CompletionCreateResponse
```

Methods:

- <code title="post /chat/completions">client.chat.completions.<a href="./src/propulsionai/resources/chat/completions.py">create</a>(\*\*<a href="src/propulsionai/types/chat/completion_create_params.py">params</a>) -> <a href="./src/propulsionai/types/chat/completion_create_response.py">CompletionCreateResponse</a></code>

# Dataset

Types:

```python
from propulsionai.types import DatasetCreateResponse
```

Methods:

- <code title="post /dataset">client.dataset.<a href="./src/propulsionai/resources/dataset/dataset.py">create</a>(\*\*<a href="src/propulsionai/types/dataset_create_params.py">params</a>) -> <a href="./src/propulsionai/types/dataset_create_response.py">DatasetCreateResponse</a></code>

## Item

Types:

```python
from propulsionai.types.dataset import ItemCreateResponse
```

Methods:

- <code title="post /dataset/item">client.dataset.item.<a href="./src/propulsionai/resources/dataset/item.py">create</a>(\*\*<a href="src/propulsionai/types/dataset/item_create_params.py">params</a>) -> <a href="./src/propulsionai/types/dataset/item_create_response.py">ItemCreateResponse</a></code>
